img.fill {
  position: absolute;
  left: 0;
  top: 0;
  min-width: 100%;
  min-height: 100%;

  max-width: 100%;
  max-height: 100%;

  border-radius: 10px;
  -o-border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;

  z-index: -1;
}

a.headerlink {
    visibility: hidden;
}

h1:hover > a.headerlink,
h2:hover > a.headerlink,
h3:hover > a.headerlink,
h4:hover > a.headerlink,
h5:hover > a.headerlink,
h6:hover > a.headerlink,
dt:hover > a.headerlink {
    visibility: visible;
}

div.figure p.caption {
    position: absolute;
    left: 0;
    bottom: 0;
    font-size: 16px;
}

.slides > article.level-2 > h2 {
    position: static;
    bottom: auto;
}
